==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Doble clic</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Doble clic para editar el texto</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Doble clic para editar el rayado</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Doble clic en una referencia a bloque para abrir el bloque</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Haga doble clic para reinicializar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Bloques</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Seleccione referencias a bloque junto con sus atributos</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Ocultar atributos cuando las referencias de bloque están ocultos</translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Right-Click</source>
        <translation>Botão direito do mouse</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Botón derecho para anular la selección</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Haga click en la entidad muestra el menú contextual</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Doble clic para seleccionar contorno</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Bloque selección</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Seleccione referencia a bloque con el atributo</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Gama cursor del ratón</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Cursor range for snap:</source>
        <translation>Gama cursor del ratón de forzar cursor:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Cursor range for picking entities:</source>
        <translation>Gama cursor para recoger entidades:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Doble clic</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Doble clic para editar el texto</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Doble clic para editar el rayado</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Doble clic en una referencia a bloque para abrir el bloque</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Haga doble clic para reinicializar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Bloques</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Seleccione referencias a bloque junto con sus atributos</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Ocultar atributos cuando las referencias de bloque están ocultos</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Highlight entity within range</source>
        <translation>Resaltar entidad dentro del rango</translation>
    </message>
    <message>
        <source>Keyboard Operations</source>
        <translation type="vanished">Operaciones del teclado</translation>
    </message>
    <message>
        <source>Angle step for rotating:</source>
        <translation type="vanished">Paso de ángulo para rotación:</translation>
    </message>
    <message>
        <location line="-211"/>
        <source>Right-Click</source>
        <translation>Botão direito do mouse</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Botón derecho para anular la selección</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Haga click en la entidad muestra el menú contextual</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Doble clic para seleccionar contorno</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Bloque selección</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Seleccione referencia a bloque con el atributo</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Gama cursor del ratón</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Cursor range for snap:</source>
        <translation>Gama cursor del ratón de forzar cursor:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Cursor range for picking entities:</source>
        <translation>Gama cursor para recoger entidades:</translation>
    </message>
</context>
</TS>
